==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/RoutingEnrichmentsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dynamic
 * @property static
 */
public data class RoutingEnrichmentsArgs(
    public val `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null,
    public val static: Output<List<StaticRoutingEnrichmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs =
        com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder()
            .`dynamic`(
                `dynamic`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .static_(
                static?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RoutingEnrichmentsArgs].
 */
@PulumiTagMarker
public class RoutingEnrichmentsArgsBuilder internal constructor() {
    private var `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null

    private var static: Output<List<StaticRoutingEnrichmentArgs>>? = null

    /**
     * @param value
     */
    @JvmName("dhahheeabvmidemb")
    public suspend fun `dynamic`(`value`: Output<List<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = value
    }

    @JvmName("yfldguqhtlbvfycg")
    public suspend fun `dynamic`(vararg values: Output<DynamicRoutingEnrichmentArgs>) {
        this.`dynamic` = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nbcumbdmstwvgeim")
    public suspend fun `dynamic`(values: List<Output<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nlfkfoyuyxhenury")
    public suspend fun static(`value`: Output<List<StaticRoutingEnrichmentArgs>>) {
        this.static = value
    }

    @JvmName("lldohdpmtnoyyhmg")
    public suspend fun static(vararg values: Output<StaticRoutingEnrichmentArgs>) {
        this.static = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fxjrusdvnwncxmyx")
    public suspend fun static(values: List<Output<StaticRoutingEnrichmentArgs>>) {
        this.static = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mddehmdhmafqkdvv")
    public suspend fun `dynamic`(`value`: List<DynamicRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("desqabycsmrcjyla")
    public suspend
    fun `dynamic`(argument: List<suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qhwbudoyxlxydfbf")
    public suspend fun `dynamic`(
        vararg
        argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("fghijxtudihdolli")
    public suspend fun `dynamic`(argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param values
     */
    @JvmName("iwdqdcloxhhanwut")
    public suspend fun `dynamic`(vararg values: DynamicRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param value
     */
    @JvmName("bacfxcasstypgywx")
    public suspend fun static(`value`: List<StaticRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ykpainvfnigtovdr")
    public suspend fun static(argument: List<suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("goeawxvyaoaqjewe")
    public suspend fun static(
        vararg
        argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rhyeupwskogalinx")
    public suspend fun static(argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param values
     */
    @JvmName("tvmflhbjwptedfab")
    public suspend fun static(vararg values: StaticRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.static = mapped
    }

    internal fun build(): RoutingEnrichmentsArgs = RoutingEnrichmentsArgs(
        `dynamic` = `dynamic`,
        static = static,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/RoutingEnrichmentsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dynamic
 * @property static
 */
public data class RoutingEnrichmentsArgs(
    public val `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null,
    public val static: Output<List<StaticRoutingEnrichmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs =
        com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder()
            .`dynamic`(
                `dynamic`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .static_(
                static?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RoutingEnrichmentsArgs].
 */
@PulumiTagMarker
public class RoutingEnrichmentsArgsBuilder internal constructor() {
    private var `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null

    private var static: Output<List<StaticRoutingEnrichmentArgs>>? = null

    /**
     * @param value
     */
    @JvmName("leiffguslrrfquvn")
    public suspend fun `dynamic`(`value`: Output<List<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = value
    }

    @JvmName("hmvywewkslrfrblv")
    public suspend fun `dynamic`(vararg values: Output<DynamicRoutingEnrichmentArgs>) {
        this.`dynamic` = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("qfhmsxphophatcmh")
    public suspend fun `dynamic`(values: List<Output<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ohlkaueupccfsvys")
    public suspend fun static(`value`: Output<List<StaticRoutingEnrichmentArgs>>) {
        this.static = value
    }

    @JvmName("hjwsdivhanyxwrgu")
    public suspend fun static(vararg values: Output<StaticRoutingEnrichmentArgs>) {
        this.static = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jtmbccqrlmiocbkk")
    public suspend fun static(values: List<Output<StaticRoutingEnrichmentArgs>>) {
        this.static = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("udmilekqpckrevod")
    public suspend fun `dynamic`(`value`: List<DynamicRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mjbcmnfthqrjtxbp")
    public suspend
    fun `dynamic`(argument: List<suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bjpeuafqyomgdqqg")
    public suspend fun `dynamic`(
        vararg
        argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("piyrogsocscltfwi")
    public suspend fun `dynamic`(argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param values
     */
    @JvmName("pfpysubieycpiwqo")
    public suspend fun `dynamic`(vararg values: DynamicRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param value
     */
    @JvmName("sufprlrvcgjcmtss")
    public suspend fun static(`value`: List<StaticRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gpmyukrqxkwqklwo")
    public suspend fun static(argument: List<suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("edipqyojliohhajl")
    public suspend fun static(
        vararg
        argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("njqloxvfyjbboogk")
    public suspend fun static(argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param values
     */
    @JvmName("gysyeubmargxygsl")
    public suspend fun static(vararg values: StaticRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.static = mapped
    }

    internal fun build(): RoutingEnrichmentsArgs = RoutingEnrichmentsArgs(
        `dynamic` = `dynamic`,
        static = static,
    )
}
